@@ -79,10 +79,10 @@ gs_read_cellfeed <- function(
 
   the_url <- this_ws$cellsfeed
   req <-
-    httr::GET(the_url,
-              omit_token_if(grepl("public", the_url)),
-              query = query,
-              if (interactive() && ddd$progress && verbose) httr::progress() else NULL) %>%
+    rGET(the_url,
+         omit_token_if(grepl("public", the_url)),
+         query = query,
+         if (interactive() && ddd$progress && verbose) httr::progress() else NULL) %>%
     httr::stop_for_status()
   rc <- content_as_xml_UTF8(req)
 
