@@ -6,7 +6,7 @@ test_that("Spreadsheets visible to authenticated user can be listed", {
 
   ss_list <- gs_ls()
   expect_is(ss_list, "googlesheet_ls")
-  expect_more_than(nrow(ss_list), 0)
+  expect_gt(nrow(ss_list), 0)
 
 })
 
